@@ -3,7 +3,6 @@ from __future__ import annotations
 
 from dataclasses import dataclass, field
 from functools import partial
-import traceback
 from typing import TYPE_CHECKING, Any, Callable, TypeVar
 
 from ecowitt2mqtt.const import (
@@ -163,7 +162,6 @@ DEFAULT_KEYS_TO_IGNORE = [
     "freq",
     "model",
     "stationtype",
-    "ws90_ver",
 ]
 
 # Map which data points tend to come with keys embedded at their end:
@@ -206,13 +204,14 @@ def get_calculator_function(
     return partial(func, ecowitt, key, data_point)
 
 
-def get_typed_value(value: T) -> float | T:
+def get_typed_value(value: T) -> int | float | T:
     """Take a string and return its properly typed counterpart (if possible)."""
+    if isinstance(value, str) and value.isdigit():
+        return int(value)
+
     try:
         return float(value)  # type: ignore[arg-type]
-    except Exception as err:  # pylint: disable=broad-except
-        LOGGER.warning("Couldn't convert value to number: %s", value)
-        LOGGER.debug("".join(traceback.format_tb(err.__traceback__)))
+    except ValueError:
         return value
 
 
