@@ -1,4 +1,4 @@
-"""Define meteorological utilities."""
+"""Define meteorological helpers."""
 from __future__ import annotations
 
 from dataclasses import dataclass
@@ -48,6 +48,9 @@ if TYPE_CHECKING:
 
 FROST_RISK_HUMIDITY_ABS_THRESHOLD = 2.8
 
+IMPERIAL_HIGH_THRESHOLD = 110.0
+IMPERIAL_LOW_THRESHOLD = -10.0
+
 ABSOLUTE_HUMIDITY_MAP = {
     UNIT_SYSTEM_IMPERIAL: WATER_VAPOR_POUNDS_PER_CUBIC_FOOT,
     UNIT_SYSTEM_METRIC: WATER_VAPOR_GRAMS_PER_CUBIC_METER,
@@ -737,6 +740,12 @@ def calculate_lightning_strike_distance(
 
     Note that lightning strike distances always have metric as the input unit system.
     """
+    try:
+        final_value = float(value)
+    except ValueError:
+        LOGGER.debug("Can't convert value to number: %s", value)
+        return CalculatedDataPoint(data_point_key=data_point_key, value=None)
+
     if ecowitt.config.output_unit_system == UNIT_SYSTEM_METRIC:
         final_value = value
     else:
@@ -971,6 +980,14 @@ def calculate_temperature(
     """Calculate temperature in the appropriate unit system."""
     temp_obj = _get_temperature_object(value, ecowitt.config.input_unit_system)
 
+    if temp_obj.f < IMPERIAL_LOW_THRESHOLD or temp_obj.f > IMPERIAL_HIGH_THRESHOLD:
+        LOGGER.warning(
+            'Value of "%s" (%s) with input unit system "%s" seems suspicious',
+            payload_key,
+            value,
+            ecowitt.config.input_unit_system,
+        )
+
     if ecowitt.config.output_unit_system == UNIT_SYSTEM_IMPERIAL:
         final_value = round(temp_obj.f, 1)
     else:
