@@ -68,6 +68,7 @@ from ecowitt2mqtt.const import (
     DATA_POINT_WEEKLY_RAIN,
     DATA_POINT_WINDCHILL,
     DATA_POINT_WRAIN_PIEZO,
+    DATA_POINT_WS90_VER,
     DATA_POINT_YEARLY_RAIN,
     DATA_POINT_YRAIN_PIEZO,
     LOGGER,
@@ -287,7 +288,6 @@ ENTITY_DESCRIPTIONS = {
     ),
     DATA_POINT_LIGHTNING_TIME: EntityDescription(
         device_class=DeviceClass.TIMESTAMP,
-        state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_1: EntityDescription(
         icon="mdi:timer",
@@ -338,6 +338,7 @@ ENTITY_DESCRIPTIONS = {
     ),
     DATA_POINT_RUNTIME: EntityDescription(
         device_class=DeviceClass.DURATION,
+        entity_category=EntityCategory.DIAGNOSTIC,
         icon="mdi:timer",
         state_class=StateClass.MEASUREMENT,
     ),
@@ -360,6 +361,7 @@ ENTITY_DESCRIPTIONS = {
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
+    DATA_POINT_WS90_VER: EntityDescription(entity_category=EntityCategory.DIAGNOSTIC),
 }
 
 PLATFORM_MAP = {
